@@ -1,6 +1,5 @@
 class BaseClass:
-    def __init__(self, name = None, **kwargs):
-        self.name = name
+    def __init__(self, **kwargs):
         for key, value in kwargs.items():
             setattr(self, key, value)
 
